DonorDrivePython
----------------

A Python reference implementation of the [Donor Drive API](https://github.com/DonorDrive/PublicAPI)

This project aims to provide a Python package the user could import to create a project to access the Donor Drive API.

For an example of what you can build to provide extra functionality around the Donor Drive API, see my project, [ElDonationTracker](http://djotaku.github.io/ELDonationTracker/) for the Extra Life charity event. It takes the Donor Drive API information and converts it to text files and HTML files that the gamers can use for live streaming during the Extra Life Event. Currently, it has the API integrated into it. The API implementation there will become the initial release in this repo.
